/*
 * sbrk.c
 */


#include<sys/types.h>
#include<signal.h>
#include<stdio.h>
#include<unistd.h>


/*
 * ꡼ѥɥ쥹
 */
static uint lastAddr;

/*
 * sbrkƥॳν
 */
void initSbrk()
{
	extern int getLastAddr(uint*);
	getLastAddr(&lastAddr);
}

void *sbrk(
	ptrdiff_t increment)
{
	uint firstAddr = lastAddr;

	if (0 < increment) {
		if (brk((void*) (lastAddr + increment)) != 0) {
			return NULL;
		}
		lastAddr += increment;
	}

	return (void*) firstAddr;
}
